#!/bin/bash

set -e

up () {
  loginctl enable-linger $USER
  podman network create pew-net || true

  # Exposed on port 8096 in pew-net  
  # TODO intel hw acceleration
  podman create \
    --name jellyfin \
    --env PUID=1000 \
    --env PGID=1000 \
    --env TZ=US/Eastern \
    --volume /bigdata/k8s-config/jellyfin/config:/config:rw \
    --volume /bigdata/media/movies:/media/movies:ro \
    --volume /bigdata/media/music:/media/music:ro \
    --network pew-net \
    ghcr.io/linuxserver/jellyfin:10.6.4-1-ls89

  podman generate systemd jellyfin --restart-policy=always --name > $HOME/.config/systemd/user/jellyfin.service
  systemctl --user daemon-reload
  systemctl start --user jellyfin || systemctl restart --user jellyfin
  systemctl enable --user jellyfin
}

down () {
  systemctl stop --user jellyfin || true
  systemctl disable --user jellyfin || true
  podman rm jellyfin || true
}

logs () {
  podman logs --follow jellyfin
}

$@
